<?php
namespace Teknisa\SM\Factory;

use Doctrine\ORM\EntityManager;

class SmAssinaturaDigitalFactory
{
    
    protected $connection;
    
    public function __construct(EntityManager $entityManager) {
        
        $this->connection = $entityManager->getConnection();
    }
    
    public function getTokenCertsign (array $params) {
        $sql = "SELECT DSTOKENCERTSIGN 
                  FROM FCT_PARAMETROGERAL
                 WHERE NRORG = :NRORG";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /*Busca o sequêncial do contrato ou proposta*/
    public function getSeqPropCont (array $params) {
        $sql = "SELECT NRSEQCONTDOC AS DOCUMENTO, NRSEQCONTRATO AS SEQUENCIAL, 'CONTRATO' AS TIPO
                  FROM FCT_CONTRATODOC
                 WHERE IDDOCUMCERTSIGN = :IDDOCUMCERTSIGN
                   AND (IDSITUACAOCONTRATO = 'D' OR IDSITUACAOCONTRATO IS NULL)
                 UNION ALL
                SELECT NRSEQORCADOC AS DOCUMENTO, NRSEQORCAMENTO AS SEQUENCIAL, 'PROPOSTA' AS TIPO
                  FROM FCT_ORCAMENTODOC
                 WHERE IDDOCUMCERTSIGN = :IDDOCUMCERTSIGN
                   AND (IDSITUACAOORCAMENTO = 'CONCLUIDO' OR IDSITUACAOORCAMENTO IS NULL)";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /*Atualiza situação das assinaturas da proposta*/
    public function updateAssinaProposta (array $params) {
        $sql = "UPDATE FCT_ASSINATDIGITALPROP
                   SET IDSITUACAO = :IDSITUACAO,
                       DSJUSTIFICARECUSA = :DSJUSTIFICARECUSA,
                       DTULTATU = SYSDATE
                 WHERE NRASSDIGITALORCA = :NRASSDIGITALORCA
                   AND NRSEQORCAMENTO = :NRSEQORCAMENTO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    /*Atualiza situação das assinaturas do contrato*/
    public function updateAssinaContrato (array $params) {
        $sql = "UPDATE FCT_ASSINATDIGITALCONTR
                   SET IDSITUACAO = :IDSITUACAO,
                       DSJUSTIFICARECUSA = :DSJUSTIFICARECUSA,
                       DTULTATU = SYSDATE
                 WHERE NRASSDIGITALCONTR = :NRASSDIGITALCONTR
                   AND NRSEQCONTRATO = :NRSEQCONTRATO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    /* Recebe o sequencial de assinatura da proposta */
    public function recebeAssinaturaOrca (array $params){
    
        $sql = "SELECT NRASSDIGITALORCA 
                 FROM FCT_ASSINATDIGITALPROP
                WHERE NRSEQORCAMENTO = :NRSEQORCAMENTO
                  AND NRCPFSIGNATARIO = :NRCPFSIGNATARIO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    /* Recebe o sequencial de assinatura do contrato */
    public function recebeAssinaturaContr (array $params){
    
        $sql = "SELECT NRASSDIGITALCONTR 
                 FROM FCT_ASSINATDIGITALCONTR
                WHERE NRSEQCONTRATO = :NRSEQCONTRATO
                  AND NRCPFSIGNATARIO = :NRCPFSIGNATARIO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
    
    /*Atualiza situação dos documentos das assinaturas da proposta*/
    public function updateAssinaDocProposta (array $params) {
        $sql = "UPDATE FCT_DOCASSINATPROP
                   SET IDSITUACAO = :IDSITUACAO,
                       DSJUSTIFICARECUSA = :DSJUSTIFICARECUSA,
                       DTULTATU = SYSDATE
                 WHERE NRSEQORCADOC = :NRSEQORCADOC
                   AND NRASSDIGITALORCA = :NRASSDIGITALORCA
                   AND NRSEQORCAMENTO = :NRSEQORCAMENTO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    /*Atualiza situação dos documentos das assinaturas do contrato */
    public function updateAssinaDocContrato (array $params) {
        $sql = "UPDATE FCT_DOCASSINATCONTR
                   SET IDSITUACAO = :IDSITUACAO,
                       DSJUSTIFICARECUSA = :DSJUSTIFICARECUSA,
                       DTULTATU = SYSDATE
                 WHERE NRSEQCONTDOC = :NRSEQCONTDOC
                  AND NRASSDIGITALCONTR = :NRASSDIGITALCONTR
                  AND NRSEQCONTRATO = :NRSEQCONTRATO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);

    }
    
    /* Recebe situação e justificativa de recusa dos documentos de assinatura da proposta */
    public function recebeDadosAssDocProp (array $params){
    
        $sql = "SELECT IDSITUACAO, DSJUSTIFICARECUSA
                  FROM FCT_DOCASSINATPROP
                 WHERE NRASSDIGITALORCA = :NRASSDIGITALORCA
                   AND NRSEQORCAMENTO = :NRSEQORCAMENTO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }
    
     /* Recebe situação e justificativa de recusa dos documentos de assinatura do contrato */
    public function recebeDadosAssDocContr (array $params){
    
        $sql = "SELECT IDSITUACAO, DSJUSTIFICARECUSA
                  FROM FCT_DOCASSINATCONTR
                 WHERE NRASSDIGITALCONTR = :NRASSDIGITALCONTR
                   AND NRSEQCONTRATO = :NRSEQCONTRATO";
        
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        return $std->fetchAll();
    }

}
?>