<?php
namespace Teknisa\SM\Service;

use Teknisa\SM\Factory\Sm00001100ItemLancamentoPropostaFactory;
use Teknisa\SM\Util\Procedure\FctCopiaFormPrecoItprop;
use Doctrine\ORM\EntityManager;
class Sm00001100ItemLancamentoPropostaService {
    protected $itensFactory;
    public function __construct (Sm00001100ItemLancamentoPropostaFactory $itensFactory, EntityManager $entityManager){
        $this->connection    = $entityManager->getConnection();
        $this->itensFactory  = $itensFactory;
    }
    /**
     * Manda executar a procedure que copia a formação de preço para a tabelça auxiliar
    **/
    public function executarProcedureFctCopiaFormPreco($nrformacao, $nrorg, $cdoperador, $nrseqorcamento, $nritemorcamento, $nrcalcform, $idformacao){
        $procedure  = new FctCopiaFormPrecoItprop($this->connection);
        $procedure->executar($nritemorcamento, $nrseqorcamento, $nrformacao, $nrorg, $cdoperador, $nrcalcform, $idformacao);
    }
    /**
     * Aplica o ajuste para os servicos filhos
    **/
    public function replicarAlteracoesItensFilhos($nrseqorcamento, $cdservorca, $vrdiferenca, $nrorg){
        $params = array(
            "NRSEQORCAMENTO" => $nrseqorcamento,
            "NRORG"          => $nrorg,
            "CDSERVORCA"     => $cdservorca,
            "VRDIFERENCA"    => $vrdiferenca
        );
        $this->itensFactory->replicarAlteracoesItensFilhos($params);
    }
    /**
     * Atualiza as quantidades dos elementos na tabela de serviço
    **/
    public function salvarNovasQuantidadesElemento($row, $cdoperador, $nrorg){
        $params = array(
            "NRSEQORCAMENTO"  => $row["NRSEQORCAMENTO"],
            "IDELEMENTO"      => $row["IDELEMENTO"],
            "CDSERVORCA"      => $row["CDSERVORCA"],
            "VRCUSTOSERV"     => $row["VRCUSTOSERV"],
            "VRTOTMENSALSERV" => $row["VRCUSTOSERV"] * $row["QTMENSAL"],
            "VRTOTMSLSAJUSTE" => $row["VRCUSTOSERV"] * $row["QTMENSAL"],
            "QTSEGUNDA"       => $row["QTSEGUNDA"],
            "QTTERCA"         => $row["QTTERCA"],
            "QTQUARTA"        => $row["QTQUARTA"],
            "QTQUINTA"        => $row["QTQUINTA"],
            "QTSEXTA"         => $row["QTSEXTA"],
            "QTSABADO"        => $row["QTSABADO"],
            "QTDOMINGO"       => $row["QTDOMINGO"],
            "QTMENSAL"        => $row["QTMENSAL"],
            "HRENTRADA"       => $row["HRENTRADA"],
            "HRSAIDA"         => $row["HRSAIDA"],
            "NRORGULTATU"     => $nrorg,
            "NRORG"           => $nrorg,
            "CDOPERULTATU"    => $cdoperador  
        );
        $this->itensFactory->salvarNovasQuantidadesElemento($params);
    }
    /**
     * Retorna a quantidade de elementos de uma composição de serviço
    **/
    public function getCountElementos($nrtipoorcamento, $nrseqorcamento, $idelementopai, $nrorg, $cdservorca){
         $params = array(
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "CDSERVORCA"      => $cdservorca,
            "NRORG"           => $nrorg,
            "IDELEMENTOPAI"   => $idelementopai,
            "NRTIPOORCAMENTO" => $nrtipoorcamento
        );
        return $this->itensFactory->getCountElementos($params);
    }
    /**
     * Exclui um item da tabela de agendamentos pendentes caso ele seja excluido na proposta
    **/
    public function excluiItemAgendPendente($nrseqorcamento, $nritemorcamento, $nrorg){
        $params = array(
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "NRITEMORCAMENTO" => $nritemorcamento,
            "NRORG"           => $nrorg
        );
        
        $this->itensFactory->excluiItemAgendPendente($params);
    }
    /**
     * Torna inativo os elementos da composição de serviço 
     * que o usuário pede para apagar
    **/
    public function inativarElementosProposta($nrseqorcamento, $nrorg, $cdservorca, $idarvore, $nrtipoorcamento, $cdoperador){
        $idelementopai = explode("_", $idarvore);
        array_pop($idelementopai);
        $idelementopai  = implode("_", $idelementopai);
        $idelementopai  = substr($idelementopai, 0, strrpos($idelementopai, "_"));
        $params = array(
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "CDSERVORCA"      => $cdservorca,
            "NRORG"           => $nrorg,
            "IDELEMENTOPAI"   => $idelementopai,
            "NRTIPOORCAMENTO" => $nrtipoorcamento,
            "CDOPERULTATU"    => $cdoperador
        );
        $this->itensFactory->inativarElementosProposta($params);
    }
    /**
     * Retira do valor do item o valor do elemento inativado
    **/
    public function alterarValorItemPai($nrseqorcamento, $cdservorca, $nrorg, $cdoperador, $nrtipoorcamento, $vrretirado){
        $params = array(
            "NRSEQORCAMENTO"  => $nrseqorcamento,
            "NRORG"           => $nrorg,
            "CDSERVORCA"      => $cdservorca,
            "NRTIPOORCAMENTO" => $nrtipoorcamento,
            "CDOPERULTATU"    => $cdoperador,
            "VRELERETIRADO"   => $vrretirado
        );
        $this->itensFactory->alterarValorItemPai($params);
    }
    /**
     * Exclui os elementos da formação de preço excluída do orcamento
     */
     public function deletarItensFormacaoProp($nrformpreco, $nrseqorcamento, $nrorg, $relacformacao){
        $params = array(
            "NRORG"               => $nrorg,
            "NRSEQORCAMENTO"      => $nrseqorcamento,
            "NRRELACFORMACAOPROP" => $relacformacao,
            "NRFORMPRECOSERVICO"  => $nrformpreco
        );
        
        $this->itensFactory->deletarItensFormacaoProp($params);
    }
    /**
     * Exclui os elementos da formação de preço excluída do orcamento
     */
     public function deletarElementosFormacaoProp($nrformpreco, $nrseqorcamento, $nrorg, $relacformacao, $nrcalcformacao){
        $params = array(
            "NRORG"               => $nrorg,
            "NRSEQORCAMENTO"      => $nrseqorcamento,
            "NRRELACFORMACAOPROP" => $relacformacao,
            "NRFORMPRECOSERVICO"  => $nrformpreco,
            "NRCALCFORMPRECSERV"  => $nrcalcformacao
        );
        
        $this->itensFactory->deletarElementosFormacaoProp($params);
    }
}